User Guide — stanpy 0.2.6 documentation
Description: A collection of examples for demonstrating the features of the stanpy.

# User Guide

Verwende stanpy in einem Projekt mit:

    import stanpy as stp

## Was ist stanpy?

Stanpy ist (in einem ersten Schritt) ein kleines Package zur Lösung gerader Stabzüge mit konstanter oder linear veränderlichen Querschnittsabmessungen nach Theorie I. oder II. Ordnung. Gelöst werden die Problemstellung mithilfe des Reduktionsverfahrens der Baustatik.

## Inhaltsverzeichnis

User Guide

- Querschnittswerte
  - EX01 Rechtecksquerschnitt
  - EX02 Zusammengesetzter Rechtecksquerschnitt
  - EX03 I-Querschnitt
  - EX04 H-Querschnitt
  - EX05 Kasten-Querschnitt
  - EX06 - Verstärkter I Querschnitt
- Querschnittswerte für Stäbe mit veränderlichen Querschnittsabmessungen
  - EX01 Rechtecksquerschnitt
  - EX02 Zusammengesetzter Rechtecksquerschnitt
  - EX03 I-Querschnitt
  - EX04 H-Querschnitt
  - EX05 Kasten-Querschnitt
  - EX06 - Verstärkter I Querschnitt
- Der gerade Stab, konstanter Querschnitt Theorie I. und II. Ordnung
  - EX01 Einfeldträger Gleichlast
  - EX02 Einfeldträger Einzellast
  - EX03 (todo: testing)
  - EX04 Stabkonstruktion Theorie II
  - Grundlagen
- Der gerade Stab, veränderlicher Querschnitt Theorie I. und II. Ordnung
  - EX01 Stabkonstruktion - R-QS
  - EX02 Stabkonstruktion - I-QS
  - Grundlagen
- Reduktionsverfahren (Übertragungsmatrizenverfahren)
  - EX01 Stabkonstruktion
  - EX02 Stabkonstruktion
  - EX03 Stabkonstruktion
  - Grundlagen

previous

Getting started

next

Querschnittswerte